@@ -246,7 +246,7 @@ class Ppos(Module):
             raw_data_dict["ReleasedHes"] = int(raw_data_dict["ReleasedHes"], 16)
             raw_data_dict["RestrictingPlan"] = int(raw_data_dict["RestrictingPlan"], 16)
             raw_data_dict["RestrictingPlanHes"] = int(raw_data_dict["RestrictingPlanHes"], 16)
-            raw_data_dict["Reduction"] = int(raw_data_dict["Reduction"], 16)
+            # raw_data_dict["Reduction"] = int(raw_data_dict["Reduction"], 16)
             receive["Ret"] = raw_data_dict
         except:...
         return receive
